#!/usr/bin/env python

from distutils.core import setup

setup(name='django-db-log',
      version='1.0.1',
      description='Django DB Error Logging',
      author='David Cramer',
      author_email='dcramer@gmail.com',
      url='http://code.google.com/p/django-db-log/',
      packages=['djangodblog'],
     )
